@@ -27,6 +27,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <arpa/inet.h>
+#if __FreeBSD__
+#include <netinet/in.h>
+#include <sys/socket.h>
+#endif
 #include <stdio.h>
 #include <errno.h>
 
