@@ -51,6 +51,7 @@ weborf_configuration_t weborf_conf = {
     .uid = ROOTUID,
     .gid = ROOTGID,
     .daemonize = false,
+    .propfind = false,
 #ifdef HAVE_LIBSSL
     .sslctx = NULL,
 #endif
@@ -246,6 +247,7 @@ void configuration_load(int argc, char *argv[]) {
         {"cgi", required_argument, 0, 'c'},
         {"cache", required_argument, 0, 'C'},
         {"mime", no_argument,0,'m'},
+        {"propfind", no_argument,0,'P'},
         {"inetd", no_argument,0,'T'},
         {"tar", no_argument,0,'t'},
         {"cert", required_argument, 0, 'S'},
@@ -281,6 +283,9 @@ void configuration_load(int argc, char *argv[]) {
         case 'T':
             weborf_conf.is_inetd=true;
             break;
+        case 'P':
+            weborf_conf.propfind = true;
+            break;
         case 'C':
             cache_init(optarg);
             break;
