@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2017-2023  Salvo "LtWorf" Tomaselli
+Copyright (C) 2017-2025  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -1232,14 +1232,31 @@ static int tar_send_dir(connection_t* connection_prop) {
     if (headers==NULL) return ERR_NOMEM;
 
 
-    //Last char is always '/', i null it so i can use default name
-    connection_prop->strfile[--connection_prop->strfile_len]=0;
+    { //Find a nice default filename
+        char* default_filename;
+        // If the last char is '/', null it so i can use default name
+        if (connection_prop->strfile[connection_prop->strfile_len - 1] == '/')
+            connection_prop->strfile[--connection_prop->strfile_len]=0;
 
-    snprintf(headers,HEADBUF ,
-             "Content-Type: application/x-gzip\r\n"
-             "Content-Disposition: attachment; filename=\"%s.tar.gz\"\r\n",
-             strrchr(connection_prop->strfile,'/')+1
-            );
+        // If
+        char* sep = strrchr(connection_prop->strfile,'/');
+        if (sep == NULL)
+            sep = connection_prop->strfile;
+
+        size_t default_size = sep - connection_prop->strfile;
+
+        if (default_size > 1)
+            default_filename = sep + 1;
+        else
+            default_filename = "compressed_directory";
+
+
+        snprintf(headers,HEADBUF,
+                "Content-Type: application/x-gzip\r\n"
+                "Content-Disposition: attachment; filename=\"%s.tar.gz\"\r\n",
+                default_filename
+                );
+    }
 
     send_http_header(200,
                      NULL,
