@@ -21,16 +21,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef WEBORF_MYSTRING_H
 #define WEBORF_MYSTRING_H
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdbool.h>
-#include <ctype.h>
-
-#include "instance.h"
 #include "types.h"
 
 void split_get_params(connection_t* connection_prop);
-bool endsWith(char *str, char *end,ssize_t len_str,ssize_t len_end);
+bool endsWith(char *str, char *end, size_t len_str, size_t len_end);
 void delChar(char *string, int pos, int n);
 void strReplace(char *string, char *substr, char with);
 void replaceEscape(char *string);
