@@ -274,7 +274,7 @@ Prints version information
 */
 void version() {
     printf("Weborf %s\n"
-           "Copyright (C) 2007-2020 Salvo 'LtWorf' Tomaselli.\n"
+           "Copyright (C) 2007-2025 Salvo 'LtWorf' Tomaselli.\n"
            "This is free software.  You may redistribute copies of it under the terms of\n"
            "the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.\n"
            "There is NO WARRANTY, to the extent permitted by law.\n\n"
@@ -369,10 +369,12 @@ void help() {
            "  -d            run as a daemon\n"
            "  -h, --help    display this help and exit\n"
            "  -I, --index   list of index files, comma-separated\n"
-           "  -i, --ip  followed by IP address to listen (dotted format)\n"
+           "  -i, --ip      followed by IP address to listen (dotted format)\n"
            "  -k, --caps    lists the capabilities of the binary\n"
            "  -m, --mime    sends content type header to clients\n"
            "  -p, --port    followed by port number to listen\n"
+           "  -P, --propfind\n"
+           "                enables the PROPFIND method with no authentication\n"
            "  -T  --inetd   must be specified when using weborf with inetd or xinetd\n"
            "  -t  --tar     will send the directories as .tar.gz files\n"
            "  -u  --uid     followed by a valid uid\n"
