@@ -1,6 +1,6 @@
 /*
 Weborf
-Copyright (C) 2009-2020  Salvo "LtWorf" Tomaselli
+Copyright (C) 2009-2025  Salvo "LtWorf" Tomaselli
 
 Weborf is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -305,8 +305,8 @@ Can serve both depth and non-depth requests. This funcion works only if
 authentication is enabled.
 */
 int propfind(connection_t* connection_prop, string_t *post_param) {
-    //Forbids the method if no authentication is in use
-    if (weborf_conf.authsock == NULL) {
+    //Forbids the method there is no authentication or it wasn't manually enabled
+    if (weborf_conf.propfind == false && weborf_conf.authsock == NULL) {
         return ERR_FORBIDDEN;
     }
 
